@@ -34,7 +34,7 @@ POSSIBILITY OF SUCH DAMAGE.
 #ifndef IMCD_H
 #define IMCD_H
 
-#define IMCD_VERSION "2022.12.22"
+#define IMCD_VERSION "2023.8.12"
 
 #include <stdint.h>
 #include <stdbool.h>
@@ -257,6 +257,19 @@ ssize_t imcd_float24_encode(
 );
 
 
+ssize_t imcd_eer_decode(
+    const uint8_t* src,
+    const ssize_t srcsize,
+    uint8_t* dst,
+    const ssize_t height,
+    const ssize_t width,
+    const int rlebits,
+    const int horzbits,
+    const int vertbits,
+    const bool superres
+);
+
+
 typedef struct {
     ssize_t len;
     uint8_t* buf;
